pub struct TurnId(pub String);Expand description
Identifies a single turn within a session.
Each call to the model within a session gets a unique TurnId. This is
used by compaction and reporting to attribute work to specific turns.
Tuple Fields
0: StringImplementations