pub struct ToolResultPart {
pub call_id: ToolCallId,
pub output: ToolOutput,
pub is_error: bool,
pub metadata: MetadataMap,
}Expand description
The result of executing a tool, sent back to the model.
Each ToolResultPart references the ToolCallPart it answers via
call_id. The is_error flag tells the model whether the tool succeeded.
Example
use agentkit_core::{ToolOutput, ToolResultPart};
let result = ToolResultPart::success("call-7", ToolOutput::text("fn main() { ... }"));
assert!(!result.is_error);Fields
call_id: ToolCallIdThe ToolCallId of the tool call this result answers.
output: ToolOutputThe output produced by the tool.
is_error: booltrue if the tool execution failed.
metadata: MetadataMapArbitrary key-value metadata.
Implementations
Sourceimpl ToolResultPart
impl ToolResultPart
Sourcepub fn success(call_id: impl Into<ToolCallId>, output: ToolOutput) -> Self
pub fn success(call_id: impl Into<ToolCallId>, output: ToolOutput) -> Self
Builds a successful tool-result part with empty metadata.
Sourcepub fn error(call_id: impl Into<ToolCallId>, output: ToolOutput) -> Self
pub fn error(call_id: impl Into<ToolCallId>, output: ToolOutput) -> Self
Builds an error tool-result part with empty metadata.
Sourcepub fn with_is_error(self, is_error: bool) -> Self
pub fn with_is_error(self, is_error: bool) -> Self
Sets the error flag explicitly.
Sourcepub fn with_metadata(self, metadata: MetadataMap) -> Self
pub fn with_metadata(self, metadata: MetadataMap) -> Self
Replaces the tool-result metadata.